@@ -265,17 +265,21 @@ class RequestQueuer(object):
         while self.getActive() < self.max_simul_reqs and self.getPending() > 0:     
             LOGGER.critical("CHECK ACTIVE LOOP")   
             hosts = self.pending_reqs.keys()
+            dispatched_requests = False
             for host in hosts:
                 if len(self.pending_reqs[host]) == 0:
                     del self.pending_reqs[host]
                 elif self._hostRequestCheck(host):
+                    dispatched_requests = True
                     req = self.pending_reqs[host].pop(0)
                     d = self._getPage(req)
                     d.addCallback(self._requestComplete, req["deferred"], host)
                     d.addErrback(self._requestError, req["deferred"], host)
                     self.last_req[host] = time.time()
                     self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
-
+            if not dispatched_requests:
+                return
+                
     def _requestComplete(self, response, deferred, host):
         self.active_reqs[host] -= 1
         self._checkActive()
